sqlobject.tests.test_blob module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_blob module

class `sqlobject.tests.test_blob.` `ImageData`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `image`
  `j` = image_data
  `q` = image_data
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_blob.ImageData`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'image_data'

`sqlobject.tests.test_blob.` `test_BLOBCol`()